/*******************************************************************************

    SALVA BATERIA EM MULTITESTER v3


    C/ PIC12F675


    AUTOR: CLAUDIO LARIOS

    DATA:04/07/2020

    Objetivo: Desligar multitester aps um perodo de tempo ajustado em um
    potencimetro.
    Este perodo tem a faixa de 15 segundos at 15 minutos
    Emite um 'bip' quando est faltando 15 segundos para acabar o tempo.
    
    Metodo Sleep e zener em srie:
        
    Consumo do pic em operao = 1 mA 
    Consumo do pic em sleep = 0,25 mA 
    Funciona com a bateria tendo tenses entre 6,5 a 9,5 volts
    
    Uso didtico

    Este arquivo  parte integrante do Picsource

*******************************************************************************/
#include <12F675.h>
#device adc=10
#use delay(clock=4000000)
#fuses NOWDT,INTRC_IO, NOCPD, NOPROTECT, MCLR, PUT, BROWNOUT
#use fast_io(a)
//bytes
#byte  trisio = 0x85
#byte  gpio   = 0x05
#bit   out    = 0x5.5  //pino 2
#bit   buzzer = 0x5.4  //pino 3

//variveis globais

unsigned int16 lido,waux=0,tempo=0;
unsigned int8   cnt;


#define VALOR_BIP 15 // 15 seg. aprox.

/*******************************************************************************
          ROTINA MAIN
*******************************************************************************/

void main() {

   setup_adc_ports(sAN2 | VSS_VDD);  //seleciona AN2 e 5v como referncia
   setup_adc(ADC_CLOCK_DIV_8 );// ajusta o clock do adc
   set_adc_channel(2); //ajusta para o pino 5 (AN2)
   setup_counters(RTCC_INTERNAL,RTCC_DIV_1);
   setup_timer_1(T1_DISABLED);//desliga timer 1
   setup_comparator(NC_NC_NC_NC);//desliga comparadores
   setup_vref(FALSE);//desliga vref
   trisio=0b001111;//ajusta entradas e sadas
   gpio=0b10000;//saida do transistor pnp=1 e o restante =0

/*******************************************************************************
           LOOP PRINCIPAL DE REPETIO
*******************************************************************************/ 

     lido=0;// l valor da tenso de entrada do pino 5

     for(cnt=0;cnt<50;cnt++){//soma mais 5 leituras
     lido+=READ_ADC();
     }
     lido/=50;//mdia das ultimas 50 leituras
     
     
     
     if(lido<VALOR_BIP) lido = VALOR_BIP;//valor mnimo
     
     tempo= lido + 1;

     
     out=1;//liga transistor

    do{
    
       tempo--;

       if(tempo == 0){
          out=0;//desliga transistor
       }

       if(tempo == VALOR_BIP){//apita 15 segundos antes de desligar p/avisar
      
        for(cnt=0; cnt<5;cnt++){
         for(waux=0;waux<300;waux++){
           buzzer=1;
           delay_us(277);
           buzzer=0;
           delay_us(277);
         }
         delay_ms(50);
        }
       }
       delay_ms(1000);
       
     }while(out==1);
    
     for(waux=0;waux<1500;waux++){//apito longo indicando o desligamento
      buzzer=1;
      delay_us(277);
      buzzer=0;
      delay_us(277);
     }
     sleep();
     delay_us(2);
}//void main()
